<?php

namespace App\Http\Livewire\AboutUs\CardTypes;

use Livewire\Component;
use Livewire\WithFileUploads;
use Illuminate\Support\Facades\Http;

class CardTypesCreate extends Component
{
    use WithFileUploads;

    public $loading = false;
    public $form = [
        'code' => '',
        'type' => '',
        'description' => '',
        'image' => null,
        'terms_and_conditions' => '',
        'faqs' => '',
        'virtual_card_font_color' => '1',
        'bg_image' => null,
        'id_number' => '2',
        'id_number_description' => '',
    ];
    public $errors = [];

    public function submit()
    {
        $this->validateForm();

        $this->loading = true;
        try {
            $formData = new \GuzzleHttp\Psr7\MultipartStream([
                [
                    'name' => 'code',
                    'contents' => $this->form['code'],
                ],
                [
                    'name' => 'type',
                    'contents' => $this->form['type'],
                ],
                [
                    'name' => 'description',
                    'contents' => $this->form['description'],
                ],
                [
                    'name' => 'terms_and_conditions',
                    'contents' => $this->form['terms_and_conditions'],
                ],
                [
                    'name' => 'faqs',
                    'contents' => $this->form['faqs'],
                ],
                [
                    'name' => 'virtual_card_font_color',
                    'contents' => $this->form['virtual_card_font_color'] == '2' ? '1' : '0',
                ],
                [
                    'name' => 'id_number',
                    'contents' => $this->form['id_number'] == '1' ? '1' : '0',
                ],
                [
                    'name' => 'id_number_description',
                    'contents' => $this->form['id_number_description'],
                ],
                [
                    'name' => 'image',
                    'contents' => $this->form['image'] ? fopen($this->form['image']->getPathname(), 'r') : '',
                    'filename' => $this->form['image'] ? $this->form['image']->getClientOriginalName() : '',
                ],
                [
                    'name' => 'bg_image',
                    'contents' => $this->form['bg_image'] ? fopen($this->form['bg_image']->getPathname(), 'r') : '',
                    'filename' => $this->form['bg_image'] ? $this->form['bg_image']->getClientOriginalName() : '',
                ],
            ]);

            $response = Http::withHeaders(['Content-Type' => 'multipart/form-data; boundary=' . $formData->getBoundary()])
                ->withBody($formData)
                ->post('https://api.example.com/cardType');

            if ($response->successful()) {
                session()->flash('success', 'New record added.');
                $this->redirect(route('card-types.list'));
            }
        } catch (\Exception $e) {
            session()->flash('error', 'Failed to create record: ' . $e->getMessage());
        }
        $this->loading = false;
    }

    public function validateForm()
    {
        $rules = [
            'form.code' => 'required|max:128',
            'form.type' => 'required|max:128',
            'form.description' => 'required|max:140',
            'form.image' => 'required',
            'form.virtual_card_font_color' => 'required',
            'form.bg_image' => 'required',
            'form.terms_and_conditions' => 'required|max:32000',
            'form.faqs' => 'required|max:32000',
            'form.id_number' => 'required',
            'form.id_number_description' => 'required_if:form.id_number,1|max:40',
        ];

        $messages = [
            'form.code.required' => 'Card Code is required!',
            'form.code.max' => 'Maximum character is 128.',
            'form.type.required' => 'Card Type Description is required!',
            'form.type.max' => 'Maximum character is 128.',
            'form.description.required' => 'Card Type Short Description is required!',
            'form.description.max' => 'Maximum character is 140.',
            'form.image.required' => 'Upload Card Type Image is required!',
            'form.virtual_card_font_color.required' => 'Virtual Card Font Color is required!',
            'form.bg_image.required' => 'Upload Card Type Cover Image is required!',
            'form.terms_and_conditions.required' => 'Terms and Condition is required!',
            'form.terms_and_conditions.max' => 'Maximum character is 32,000.',
            'form.faqs.required' => 'FAQs is required!',
            'form.faqs.max' => 'Maximum character is 32,000.',
            'form.id_number.required' => 'ID Number is required!',
            'form.id_number_description.required_if' => 'ID Number Description is required!',
            'form.id_number_description.max' => 'Maximum character is 40.',
        ];

        $this->errors = [];
        try {
            $this->validate($rules, $messages);
        } catch (\Exception $e) {
            $this->errors = collect($e->errors())->flatten()->toArray();
            throw $e;
        }
    }

    public function render()
    {
        return view('livewire.about-us.card-types.card-types-create');
    }
}