<?php

namespace App\Http\Livewire\AboutUs\CardTypes;

use Livewire\Component;
use Illuminate\Support\Facades\Http;

class CardTypesView extends Component
{
    public $card;

    public function mount($id)
    {
        try {
            $this->card = $this->fetchFromApi("https://api.example.com/cardType/{$id}");
        } catch (\Exception $e) {
            session()->flash('error', 'Failed to load card type details: ' . $e->getMessage());
            return redirect()->route('card-types.list');
        }
    }

    private function fetchFromApi($url)
    {
        $response = Http::get($url);
        return $response->json()['data'] ?? null;
    }

    public function delete($uuid)
    {
        try {
            $response = Http::delete("https://api.example.com/cardType/{$uuid}");
            if ($response->successful()) {
                session()->flash('success', 'Record was successfully deleted.');
                return redirect()->route('card-types.list');
            }
        } catch (\Exception $e) {
            session()->flash('error', 'Failed to delete record: ' . $e->getMessage());
        }
    }

    public function render()
    {
        return view('livewire.about-us.card-types.card-types-view', ['card' => $this->card]);
    }
}