<?php

namespace App\Livewire\UserManagement;

use Livewire\Component;
use App\Services\ApiService;
use Illuminate\Support\Facades\Session;
use Illuminate\Support\Facades\Log;

class View extends Component
{
    public $userInfo = null;
    public $mounted = false;
    public $id;

    protected $apiService;

    public function boot(ApiService $apiService)
    {
        $this->apiService = $apiService;
    }

    public function mount($id)
    {
        $this->id = $id;

        try {
            $response = $this->apiService->get("admin/{$id}");
            if ($response && isset($response['data'])) {
                $this->userInfo = $response['data'];
                $this->mounted = true;
                Log::info('User data loaded', ['source' => 'UserManagementView']);
            }
        } catch (\Exception $e) {
            Session::flash('error', 'Something went wrong loading data: ' . $e->getMessage());
            Log::error('Failed to load user data', ['error' => $e->getMessage(), 'source' => 'UserManagementView']);
            if ($e->getCode() == 404) {
                return redirect()->route('404');
            }
            $this->mounted = true;
        }
    }

    public function delete()
    {
        try {
            $response = $this->apiService->delete("admin/{$this->userInfo['admin_uuid']}");
            if ($response && isset($response['status']) && $response['status'] === 200) {
                Session::flash('success', 'Record was successfully deleted.');
                Log::info('User deleted successfully', ['source' => 'UserManagementView']);
                return redirect()->route('user-management');
            }
        } catch (\Exception $e) {
            Session::flash('error', 'Something went wrong deleting record: ' . $e->getMessage());
            Log::error('Failed to delete user', ['error' => $e->getMessage(), 'source' => 'UserManagementView']);
        }
    }

    public function render()
    {
        // Check role-based access
        $userInfo = Session::get('userInfo');
        if (!$userInfo || $userInfo['role'] != 1) {
            return redirect()->route('404');
        }

        return view('livewire.user-management.view')->layout('layouts.app', ['title' => 'View User']);
    }
}