@extends('layouts.app')

@section('content')
    <div class="container mt-4">
        <div class="card">
            <div class="card-header d-flex justify-content-between align-items-center">
                <h4>Promotion Details</h4>
                <div>
                    <a href="{{ route('promotions.edit', $id) }}" class="btn btn-warning">Update</a>
                    <button class="btn btn-danger" wire:click="delete">Delete</button>
                </div>
            </div>
            <div class="card-body">
                @if($promotion)
                    <div class="mb-3">
                        @if($promotion['image'])
                            <img src="{{ $promotion['image'] }}" alt="Promotion Image" style="width: 313px; height: 164px; object-fit: fill;">
                        @else
                            <p>No image available.</p>
                        @endif
                    </div>

                    <div class="mb-4">
                        <h5 class="fw-bold">Content Details</h5>
                        <div class="row mb-2">
                            <div class="col-3 fw-semibold">Title:</div>
                            <div class="col-9">{{ $promotion['title'] ?? 'N/A' }}</div>
                        </div>
                        <div class="row mb-2">
                            <div class="col-3 fw-semibold">Description:</div>
                            <div class="col-9">{{ $promotion['description'] ?? 'N/A' }}</div>
                        </div>
                        <div class="row mb-2">
                            <div class="col-3 fw-semibold">Branch:</div>
                            <div class="col-9">
                                @if($promotion['stations'] && count($promotion['stations']) > 0)
                                    @foreach($promotion['stations'] as $station)
                                        {{ $station['description'] }}@if(!$loop->last), @endif
                                    @endforeach
                                @else
                                    All
                                @endif
                            </div>
                        </div>
                        <div class="row mb-2">
                            <div class="col-3 fw-semibold">Add in Top 2 Promos:</div>
                            <div class="col-9">{{ $promotion['is_toppromotion'] == 1 ? 'Yes' : 'No' }}</div>
                        </div>
                        <div class="row mb-2">
                            <div class="col-3 fw-semibold">Add in GPS:</div>
                            <div class="col-9">{{ $promotion['is_gps'] == 1 ? 'Yes' : 'No' }}</div>
                        </div>
                        <div class="row mb-2">
                            <div class="col-3 fw-semibold">Status:</div>
                            <div class="col-9">{{ $promotion['status'] ?? 'N/A' }}</div>
                        </div>
                        <div class="row mb-2">
                            <div class="col-3 fw-semibold">Promo Type:</div>
                            <div class="col-9">{{ $promotion['promo_type']['name'] ?? 'N/A' }}</div>
                        </div>
                    </div>

                    <div>
                        <h5 class="fw-bold">Schedule Details</h5>
                        <div class="row mb-2">
                            <div class="col-3 fw-semibold">Start Appearance Date:</div>
                            <div class="col-9">{{ \Carbon\Carbon::parse($promotion['date_start'])->format('d-M-Y') }}</div>
                        </div>
                        <div class="row mb-2">
                            <div class="col-3 fw-semibold">End Appearance Date:</div>
                            <div class="col-9">{{ \Carbon\Carbon::parse($promotion['date_end'])->format('d-M-Y') }}</div>
                        </div>
                        <div class="row mb-2">
                            <div class="col-3 fw-semibold">Start Time:</div>
                            <div class="col-9">{{ \Carbon\Carbon::parse($promotion['date_start'])->format('H:i') }}</div>
                        </div>
                        <div class="row mb-2">
                            <div class="col-3 fw-semibold">End Time:</div>
                            <div class="col-9">{{ \Carbon\Carbon::parse($promotion['date_end'])->format('H:i') }}</div>
                        </div>
                        <div class="row mb-2">
                            <div class="col-3 fw-semibold">Created By:</div>
                            <div class="col-9">{{ $promotion['created_by'] ?? 'N/A' }}</div>
                        </div>
                        <div class="row mb-2">
                            <div class="col-3 fw-semibold">Date Created:</div>
                            <div class="col-9">{{ \Carbon\Carbon::parse($promotion['created_at'])->format('d-M-Y') }}</div>
                        </div>
                        <div class="row mb-2">
                            <div class="col-3 fw-semibold">Last Updated By:</div>
                            <div class="col-9">{{ $promotion['updated_by'] ?? 'N/A' }}</div>
                        </div>
                        <div class="row mb-2">
                            <div class="col-3 fw-semibold">Last Updated Date:</div>
                            <div class="col-9">{{ \Carbon\Carbon::parse($promotion['updated_at'])->format('d-M-Y') }}</div>
                        </div>
                    </div>
                @else
                    <p>Loading promotion details...</p>
                @endif
            </div>
        </div>
    </div>
@endsection