<form wire:submit.prevent="save" novalidate>
    @include('partials.header-form', ['title' => $title, 'loading' => $loading, 'disabled' => false, 'actionBtnName' => 'Submit'])

    <div class="row mb-3">
        <label for="title" class="col-sm-5 col-form-label">Title</label>
        <div class="col-sm-7">
            <input type="text" class="form-control @error('title') is-invalid @enderror" id="title" wire:model="title" placeholder="Title">
            @error('title') <div class="invalid-feedback">{{ $message }}</div> @enderror
        </div>
    </div>

    <div class="row mb-3">
        <label for="description" class="col-sm-5 col-form-label">Description</label>
        <div class="col-sm-7">
            <textarea class="form-control @error('description') is-invalid @enderror" id="description" wire:model="description" rows="6" placeholder="Description"></textarea>
            @error('description') <div class="invalid-feedback">{{ $message }}</div> @enderror
        </div>
    </div>

    <div class="row mb-3">
        <label for="image" class="col-sm-5 col-form-label">Upload Image</label>
        <div class="col-sm-7">
            <input type="file" class="form-control @error('image') is-invalid @enderror" id="image" wire:model="image" accept=".jpg,.png,.gif">
            <small>Image Size: 1020 x 621, Maximum File Size: 100KB</small>
            @error('image') <div class="invalid-feedback">{{ $message }}</div> @enderror
        </div>
    </div>

    <div class="row mb-3">
        <label for="station_uuid" class="col-sm-5 col-form-label">Branch</label>
        <div class="col-sm-7">
            <select multiple class="form-control @error('station_uuid') is-invalid @enderror" id="station_uuid" wire:model="station_uuid">
                @foreach ($branches as $branch)
                    <option value="{{ $branch['value'] }}">{{ $branch['label'] }}</option>
                @endforeach
            </select>
            @error('station_uuid') <div class="invalid-feedback">{{ $message }}</div> @enderror
        </div>
    </div>

    <div class="row mb-3">
        <label for="date_start" class="col-sm-5 col-form-label">Start Date</label>
        <div class="col-sm-7">
            <input type="date" class="form-control @error('date_start') is-invalid @enderror" id="date_start" wire:model="date_start">
            @error('date_start') <div class="invalid-feedback">{{ $message }}</div> @enderror
        </div>
    </div>

    <div class="row mb-3">
        <label for="date_end" class="col-sm-5 col-form-label">End Date</label>
        <div class="col-sm-7">
            <input type="date" class="form-control @error('date_end') is-invalid @enderror" id="date_end" wire:model="date_end">
            @error('date_end') <div class="invalid-feedback">{{ $message }}</div> @enderror
        </div>
    </div>

    <div class="row mb-3">
        <label for="start_time" class="col-sm-5 col-form-label">Start Time</label>
        <div class="col-sm-7">
            <input type="time" class="form-control @error('start_time') is-invalid @enderror" id="start_time" wire:model="start_time">
            @error('start_time') <div class="invalid-feedback">{{ $message }}</div> @enderror
        </div>
    </div>

    <div class="row mb-3">
        <label for="end_time" class="col-sm-5 col-form-label">End Time</label>
        <div class="col-sm-7">
            <input type="time" class="form-control @error('end_time') is-invalid @enderror" id="end_time" wire:model="end_time">
            @error('end_time') <div class="invalid-feedback">{{ $message }}</div> @enderror
        </div>
    </div>

    <div class="row mb-3">
        <label class="col-sm-5 col-form-label">Add in Top 2 Promos</label>
        <div class="col-sm-7">
            <div class="form-check form-check-inline">
                <input class="form-check-input" type="radio" id="top_yes" wire:model="is_toppromotion" value="1" {{ $is_toppromotion_disabled ? 'disabled' : '' }}>
                <label class="form-check-label" for="top_yes">Yes</label>
            </div>
            <div class="form-check form-check-inline">
                <input class="form-check-input" type="radio" id="top_no" wire:model="is_toppromotion" value="0">
                <label class="form-check-label" for="top_no">No</label>
            </div>
            @error('is_toppromotion') <div class="text-danger">{{ $message }}</div> @enderror
        </div>
    </div>

    <div class="row mb-3">
        <label for="promo_type" class="col-sm-5 col-form-label">Promo Type</label>
        <div class="col-sm-7">
            <select class="form-control @error('promo_type') is-invalid @enderror" id="promo_type" wire:model="promo_type">
                <option value="">Select Promo Type</option>
                @foreach ($promoTypes as $type)
                    <option value="{{ $type['value'] }}">{{ $type['label'] }}</option>
                @endforeach
            </select>
            @error('promo_type') <div class="invalid-feedback">{{ $message }}</div> @enderror
        </div>
    </div>

    <div class="row mb-3">
        <label class="col-sm-5 col-form-label">Add in GPS</label>
        <div class="col-sm-7">
            <div class="form-check form-check-inline">
                <input class="form-check-input" type="radio" id="gps_yes" wire:model="is_gps" value="1">
                <label class="form-check-label" for="gps_yes">Yes</label>
            </div>
            <div class="form-check form-check-inline">
                <input class="form-check-input" type="radio" id="gps_no" wire:model="is_gps" value="0">
                <label class="form-check-label" for="gps_no">No</label>
            </div>
            @error('is_gps') <div class="text-danger">{{ $message }}</div> @enderror
        </div>
    </div>
</form>